/*
 * Copyright (C) 2003  Stefan Armbruster [stefan@armbruster-it.de]
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * $Id: IterativeSubModel.java 114 2005-12-09 15:51:51Z christianc $
 */
package org.barracudamvc.contrib.sam.models;

import java.util.Collection;

import org.apache.log4j.Logger;
import org.barracudamvc.core.comp.TemplateDirective;
import org.barracudamvc.core.comp.TemplateModel;

/**
 * Assume a "supermodel" containing a List of Lists (a 2 dimensional structure).
 * An outer ("enclosing") model iterates over the the 1st dimension. The IterativeSubModel
 * asks the enclosing model for its current value and iterates over the 2nd dimension
 * @author Stefan Armbruster
 * @version $Id: IterativeSubModel.java 114 2005-12-09 15:51:51Z christianc $
 */
public class IterativeSubModel extends IteratorModel {

    protected static Logger logger = Logger.getLogger(IterativeSubModel.class);

    /** reference to enclosing model */
    protected TemplateModel enclosing;
    protected String key;

    /** initialize the model
     * @param name Name of the model
     * @param enclosing reference to surrounding model
     */
    public IterativeSubModel(String name, String key, TemplateModel enclosing) {
        super(name);
        this.enclosing = enclosing;
        this.key = key;
    }

    public void preIterate() {
        if (enclosing==null) {
            logger.error("you didn't specify a valid enclosing model");
            return;
        }
        Object referenceMain = enclosing.getItem(new TemplateDirective(null, null, key, null));
        /*if (referenceMain == null) {
            logger.error("the enclosing model (type: " + enclosing.getClass().getName() + ") doesn't have a " + key + " result for getItem");
            return;
        }*/

        // if enclosing model delivers a List, use it. Otherwise, get a list out of the reference by calling getListFromReference
        Collection coll = null;
        if (referenceMain instanceof Collection) {
            logger.debug("List: " + (Collection)referenceMain);
            coll = (Collection)referenceMain;
        } else {
            logger.info("the enclosing model (type: " + enclosing.getClass().getName() + ") doesn't deliver a Collection, so call getListFromReference");
            coll = getListFromReference(referenceMain);
        }
        if (coll == null) {
            logger.error("could not get a list from model " + enclosing.getClass().getName());
        } else {
            setIterator( coll.iterator() );
        }
        super.preIterate();
    }

    /** dummy implementation, to be overridden in subclasses */
    protected Collection getListFromReference(Object ref) {
        throw new UnsupportedOperationException("getListFromReference is not yet implemented");
    }

    public Object getItem(String key) {
        logger.debug("getting key : " + key);
        return _current;
    }
}
