/*
 * Copyright (C) 2003  Christian Cryder [christianc@granitepeaks.com]
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * $Id: BTemplateGateway.java 114 2005-12-09 15:51:51Z christianc $
 */
package org.barracudamvc.core.comp.helper;

import java.io.IOException;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.log4j.Logger;
import org.barracudamvc.core.comp.BComponent;
import org.barracudamvc.core.comp.BTemplate;
import org.barracudamvc.core.comp.DefaultTemplateView;
import org.barracudamvc.core.comp.TemplateModel;
import org.barracudamvc.core.comp.ViewContext;
import org.barracudamvc.core.util.dom.DefaultDOMLoader;
import org.w3c.dom.Document;

/**
 * <p>A custom implementation of the component gateway tailored for
 * template components. All you have to do is instantiate the class
 * with the name of the template and a reference to the model; it takes 
 * care of everything else.
 */
public abstract class BTemplateGateway extends ComponentGateway {

    //public vars...eventually, these should probably be final
    protected static final Logger logger = Logger.getLogger(BTemplateGateway.class.getName());
    

    //-------------------- TemplateGateway -----------------------
    /**
     * Return an instance of the template model
     */
    public abstract TemplateModel getTemplateModel();
    
    /**
     * Return an instance of the template class (must implement Document)
     */
    public abstract Class getTemplateClass();
    
    /**
     * Handle the default HttpRequest. 
     */
    public Document handleDefault (BComponent root, ViewContext vc, HttpServletRequest req, HttpServletResponse resp) throws IOException {
        //load the localized DOM template
//csc_061702.1        Document page = DefaultDOMLoader.getGlobalInstance().getDOM(getTemplateClass());
        Document page = DefaultDOMLoader.getGlobalInstance().getDOM(getTemplateClass(), vc.getViewCapabilities().getClientLocale());    //csc_061702.1

        //create a template component and bind it to the views
//        TemplateView tv = new DefaultTemplateView(page.getDocumentElement());
//        BTemplate templateComp = new BTemplate(getTemplateModel(), tv);
        BTemplate templateComp = new BTemplate(getTemplateModel());
        templateComp.setView(new DefaultTemplateView(page.getDocumentElement()));
        root.addChild(templateComp);

        //return the page
        return page;
    }


}
