package org.barracudamvc.examples.xmlc;

import java.io.IOException;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.barracudamvc.core.comp.AbstractTemplateModel;
import org.barracudamvc.core.comp.BComponent;
import org.barracudamvc.core.comp.BLink;
import org.barracudamvc.core.comp.BTemplate;
import org.barracudamvc.core.comp.BText;
import org.barracudamvc.core.comp.DefaultTemplateView;
import org.barracudamvc.core.comp.IterativeModel;
import org.barracudamvc.core.comp.ViewContext;
import org.barracudamvc.core.comp.helper.ComponentGateway;
import org.barracudamvc.core.util.dom.DOMWriter;
import org.barracudamvc.core.util.dom.DefaultDOMLoader;
import org.barracudamvc.core.util.dom.DefaultDOMWriter;
import org.w3c.dom.Document;
import org.w3c.dom.Node;

/**
 * Test TemplateHelper's ability to a) remove empty tags and 
 * b) support nested directives
 */
public class CompEx6 extends ComponentGateway {

    //-------------------- ComponentGateway ----------------------
    /**
     * Handle the default HttpRequest. 
     */
    public Document handleDefault (BComponent root, ViewContext vc, HttpServletRequest req, HttpServletResponse resp) throws IOException {
        //load the localized DOM template
        Document page = DefaultDOMLoader.getGlobalInstance().getDOM(CompEx6HTML.class);

        //create a template component and bind it to the views
        BTemplate templateComp = new BTemplate(new LocalTemplateModel(req));
        templateComp.addModel(new LocalIterativeModel("Cntr1",2));
        templateComp.addModel(new LocalIterativeModel("Cntr2",3));
        templateComp.setView(new DefaultTemplateView(page.getDocumentElement()));
        root.addChild(templateComp);

        //return the page
        return page;
    }

    /**
     * <p>Get a DOMWriter. By default, we use a DefaultDOMWriter. If
     * you'd like to use something else, override this method.
     *
     * @return a DOMWriter to be used to render the DOM
     */
    public DOMWriter getDOMWriter() {
        //return DefaultDOM writer
        return new DefaultDOMWriter(true);
    }

    //--------------- TemplateModel --------------------------
    /**
     * LocalTemplateModel
     */
    class LocalTemplateModel extends AbstractTemplateModel {
    
        HttpServletRequest req = null;
        int attr = 0;
        int cntr = 0;
                        
        public LocalTemplateModel(HttpServletRequest ireq) {
            req = ireq;
        }
        
        //register the model by name
        public String getName() {return "Test1";}
        
        //provide items by key
        public Object getItem(String key) {
            ViewContext vc = getViewContext();
            if (key.equals("NullItem")) {
                return null;
            } else if (key.equals("Link1")) {
                BLink blink = new BLink("some text","someurl", vc);
                return blink;
            } else if (key.equals("Image1")) {
                return "/Barracuda/images/key.gif";
            } else if (key.equals("Markup1")) {
                try {
                    CompEx6aHTML snippetPage = (CompEx6aHTML) DefaultDOMLoader.getGlobalInstance().getDOM(CompEx6aHTML.class);
                    Node targetNode = snippetPage.getElementMarkupBlockID();
//csc_072604_2                    return vc.getElementFactory().getDocument().importNode(targetNode, true);                    
                    return vc.getDocument().importNode(targetNode, true);   //csc_072604_2
                } catch (IOException e) {
                    return "Unable to find "+key+" snippet:"+e;
                }
            } else if (key.equals("Text1")) {
                return "Some text goes here...";
            } else if (key.startsWith("GetAttr")) {
                BComponent comp = new BComponent();
                comp.setAttr("cntr", ""+(++attr));
//System.out.println("Returning node="+attr+" for key:"+key);
                return comp;
            } else {
                return super.getItem(key);
            }
        }
    }

    /**
     * LocalIterativeModel
     */
    class LocalIterativeModel extends AbstractTemplateModel implements IterativeModel {
    
        String modelName = null;
        int max = -1;
        int cntr = -1;
                        
        public LocalIterativeModel(String imodelName, int imax) {
            modelName = imodelName;
            max = imax;
        }
        
        //register the model by name
        public String getName() {return modelName;}
        
        //provide items by key
        public Object getItem(String key) {
            if (key.equals("Cntr")) {
                return new BText("[model "+modelName+"]."+"Iterative Item"+cntr);
            } else {
                return super.getItem(key);
            }
        }


        public void preIterate() {
            cntr = 0;
        }
        
        public void postIterate() {
            cntr = 99;
        }
        
        public boolean hasNext() {
            return (cntr<max);
        }
        
        public void loadNext() {
            cntr++;
        }
        
    }
}
