/*
 * Copyright (C) 2003  Christian Cryder [christianc@granitepeaks.com]
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * $Id: LocalizeXmlcUtilsImpl.java 114 2005-12-09 15:51:51Z christianc $
 */
package org.barracudamvc.taskdefs;

import java.io.File;
import java.util.Arrays;
import java.util.StringTokenizer;

import org.enhydra.xml.xmlc.taskdef.DefaultXmlcUtilsImpl;


/**
 * Implementation of the XmlcUtils class for use when localizing files
 *
 * @author Robert Leftwich
 * @version 1.0
 */
public class LocalizeXmlcUtilsImpl extends DefaultXmlcUtilsImpl {

    //===========================================================================
    // CONSTRUCTORS
    //===========================================================================

    /**
     * Construct default LocalizeXmlcUtilsImpl.  This was formerly protected to
     * force the use of XmlcUtils.create() factory method. However, since
     * XmlcUtils is now in a separate package (org.enhydra.xml.xmlc.taskdef), it
     * is necessary to make this constructor public. It should be understood,
     * however, that one should use XmlcUtils.create() rather than using this
     * constructor directly.
     */
    public LocalizeXmlcUtilsImpl() {
        super();
    }

    //===========================================================================
    // QUERY METHODS
    //===========================================================================

    /**
     * Build a Java class name out of the specified components.
     * This implementation checks to see if the file name is
     * localized (i.e. it has a _xx suffix - where xx is a country
     * code). If it does, it adds the modifier prior to the _xx
     * suffix but after the file name.
     * e.g. config_en becomes configHTML_en if the modifier is HTML
     *
     * @param theFullBaseFileName
     *               The full base file name (specified with '/' separators)
     *               and no file type. e.g. "org.enhydra.test"
     * @param theModifier
     *               The file modifier to append to the class name
     *               e.g. HTML
     * @return A Java class name string
     */
    public String buildClassName(String theFullBaseFileName, String theModifier) {
        // Synthesise class name based on path and filename based on filename
        String baseFileName = theFullBaseFileName;
        String localeStr = "";

        //first and foremost, figure out if we're looking at an
        //existing localized template file. If so, split it into
        //baseFileName and localeStr segments.
        if (theFullBaseFileName.indexOf("_")>0) {
            int offset = 0;
            String tfile = theFullBaseFileName;
            StringTokenizer st = new StringTokenizer(tfile, "_");
            while (st.hasMoreTokens()) {
              String token = st.nextToken();
              int pos = Arrays.binarySearch(Localize.countryCodes, token);
              if (pos>-1 && pos<Localize.countryCodes.length && Localize.countryCodes[pos].equals(token)) break;
              else offset += token.length()+1;
            }
            if (offset<baseFileName.length()) {
              baseFileName = theFullBaseFileName.substring(0,offset-1);
              localeStr = theFullBaseFileName.substring(offset-1);
            }
            //System.out.println("base filename:"+baseFileName+" localeStr:"+localeStr+" offset:"+offset);
        }

        String className = baseFileName.replace('/', '.');
        className = className.replace(File.separatorChar, '.') + theModifier + localeStr;
        return className;
    }

}
