/*
 * Copyright (C) 2003  Christian Cryder [christianc@granitepeaks.com]
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * $Id: MockHttpServletRequest.java 114 2005-12-09 15:51:51Z christianc $
 */
package org.barracudamvc.testbed.servlet;

import java.io.BufferedReader;
import java.io.IOException;
import java.security.Principal;
import java.util.ArrayList;
import java.util.Enumeration;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Locale;
import java.util.Map;
import java.util.StringTokenizer;

import javax.servlet.RequestDispatcher;
import javax.servlet.ServletInputStream;
import javax.servlet.http.Cookie;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpSession;

import org.barracudamvc.plankton.data.Param;

/**
 * <p>This class provides a mockup implementation for the HttpServletRequest.
 * Note that not all the methods are implemented...you may need to extend/override
 * to get the behaviour you expect. If the behaviour is common to all
 * servlet requests, add it back in here. Note also that all properties of
 * this class are public, allowing you to access them directly (makes assertions
 * easier) 
 */
public class MockHttpServletRequest implements HttpServletRequest {

    public String paramStr = null;
    public List paramList = new ArrayList();
    public Map hdrMap = new HashMap();

    /**
     * Noargs constructor
     */
    public MockHttpServletRequest() {
        this(null);
    }
    
    /**
     * Create a request with a given param String
     */
    public MockHttpServletRequest(String paramStr) {
        if (paramStr!=null) setParamStr(paramStr);
    
    }

    //-------------------- MockHttpServletRequest ----------------
    public void setParamStr(String paramStr) {
        //clear the paramList
        paramList.clear();
        if (paramStr==null) return;

        //convert the incoming parameters into param vals and store them in the list
        String delimiter = "&";
        StringTokenizer st = new StringTokenizer(paramStr, delimiter);
        while (st.hasMoreTokens()) {
            String segment = st.nextToken();
            StringTokenizer stsub = new StringTokenizer(segment, "=");
            String key = (String) stsub.nextElement();
            String value = (String) stsub.nextElement();
            paramList.add(new Param(key, value));
        }
    }
    
    public void setHeader(String hdrName, String hdrValue) {
        List hdrs = new ArrayList(1);
        hdrs.add(hdrValue);
        hdrMap.put(hdrName, hdrs);    
    }

    public void addHeader(String hdrName, String hdrValue) {
        List hdrs = (List) hdrMap.get(hdrName);
        if (hdrs==null) {
            setHeader(hdrName, hdrValue);
        } else {
            hdrs.add(hdrValue);        
        }
    }



    //-------------------- HttpServletRequest --------------------
    public String getAuthType() {return null;}
    public String getContextPath() {return null;}
    public Cookie[] getCookies() {return null;}
    public long getDateHeader(String name) {return -1;}
    
    /**
     * Get a header
     */
    public String getHeader(String hdrName) {
        List hdrs = (List) hdrMap.get(hdrName);
        if (hdrs==null) {
            return null;
        } else {
            return (String) hdrs.get(0);
        }
    }
    
    /**
     * Get a list of header names
     */
    public Enumeration getHeaderNames() {
        Iterator it = hdrMap.keySet().iterator();
        List keys = new ArrayList();
        while (it.hasNext()) {
            keys.add(it.next());
        }
        return new LocalEnumerator(keys);
    }
    
    /**
     * get a list of header values for a given name
     */
    public Enumeration getHeaders(String hdrName) {
        return new LocalEnumerator((List) hdrMap.get(hdrName));
    }

    public int getIntHeader(String name) {return -1;}
    public String getMethod() {return null;}
    public String getPathInfo() {return null;}
    public String getPathTranslated() {return null;}
    public String getQueryString() {return null;}
    public String getRemoteUser() {return null;}
    public String getRequestedSessionId() {return null;}
    public String getRequestURI() {return null;}
    public String getServletPath() {return null;}
    public HttpSession getSession() {return null;}
    public HttpSession getSession(boolean create) {return null;}
    public Principal getUserPrincipal() {return null;}
    public boolean isRequestedSessionIdFromCookie() {return false;}
    public boolean isRequestedSessionIdFromUrl() {return false;}
    public boolean isRequestedSessionIdFromURL() {return false;}
    public boolean isRequestedSessionIdValid() {return false;}
    public boolean isUserInRole(String role) {return false;}

    //-------------------- ServletRequest ------------------------
    public Object getAttribute(String name) {return null;}
    public Enumeration getAttributeNames() {return null;}
    public void setCharacterEncoding(String s) {}
    public String getCharacterEncoding() {return null;}
    public int getContentLength() {return -1;}
    public String getContentType() {return null;}
    public ServletInputStream getInputStream() throws IOException {return null;}
    public Locale getLocale() {return null;}
    public Enumeration getLocales() {return null;}
    public Map getParameterMap() {return null;} //probably need to integrate this with getParameter structure below
    public StringBuffer getRequestURL() {return null;}

    /**
     * get a parameter
     */
    public String getParameter(String name) {
        Iterator it = paramList.iterator();
        while (it.hasNext()) {
            Param param = (Param) it.next();
            if (param.getKey().equals(name)) {
                return param.getValue();
            }
        }
        return null;
    }

    /**
     * get parameter names
     */
    public Enumeration getParameterNames() {
        return new LocalEnumerator(paramList);
    }

    /**
     * get parameter values
     */
    public String[] getParameterValues(String name) {
        List valueList = new ArrayList(paramList.size());
        Iterator it = paramList.iterator();
        while (it.hasNext()) {
            Param param = (Param) it.next();
            if (param.getKey().equals(name)) valueList.add(param.getValue());
        }
        int idx = -1;
        String[] valueArr = new String[valueList.size()];
        it = valueList.iterator();
        while (it.hasNext()) {
            valueArr[++idx] = (String) it.next();
        }
        if (valueArr.length==0) return null;
        else return valueArr;
    }
    public String getProtocol() {return null;}
    public BufferedReader getReader() throws IOException {return null;}
    public String getRealPath(String path) {return null;}
    public String getRemoteAddr() {return null;}
    public String getRemoteHost() {return null;}
    public RequestDispatcher getRequestDispatcher(String path) {return null;}
    public String getScheme() {return null;}
    public String getServerName() {return null;}
    public int getServerPort() {return -1;}
    public boolean isSecure() {return false;}
    public void removeAttribute(String name) {}
    public void setAttribute(String name, Object o) {}



    //-------------------- Utilities -----------------------------
    /**
     * This inner class implements Enumaration. It will effectively
     * enumerate over all of the parameter key names.
     */
    class LocalEnumerator implements Enumeration {
        List keyList = null;
        Iterator it = null;

        public LocalEnumerator(List iparamList) {
            if (iparamList!=null) {
                keyList = new ArrayList(iparamList.size());
                it = iparamList.iterator();
                while (it.hasNext()) {
                    Object o = it.next();
                    if (o instanceof Param) {
                        Param param = (Param) o;
                        if (!keyList.contains(param.getKey())) keyList.add(param.getKey());
                    } else {
                        keyList.add(o);
                    }
                }
                it = keyList.iterator();
            }
        }

        public boolean hasMoreElements() {
            return (it!=null && it.hasNext());
        }

        public Object nextElement() {
            return it.next();
        }
        
        public String toString() {
            return super.toString()+" {"+keyList.size()+" items}";
        }
    }


}
