package org.barracudamvc.tutorials.comp;

import java.io.IOException;
import java.util.Locale;
import java.util.ResourceBundle;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.barracudamvc.core.comp.AbstractTemplateModel;
import org.barracudamvc.core.comp.BComponent;
import org.barracudamvc.core.comp.BTemplate;
import org.barracudamvc.core.comp.DefaultTemplateView;
import org.barracudamvc.core.comp.IterativeModel;
import org.barracudamvc.core.comp.ViewContext;
import org.barracudamvc.core.comp.helper.ComponentGateway;
import org.barracudamvc.core.util.dom.DefaultDOMLoader;
import org.barracudamvc.plankton.l10n.Localize;
import org.barracudamvc.tutorials.xmlc.HelloWorld4HTML;
import org.barracudamvc.tutorials.xmlc.HelloWorld4_headerHTML;
import org.w3c.dom.Document;
import org.w3c.dom.Node;

/**
 * Here's an example of HelloWorld using the BTemplate
 * component
 */
public class HelloWorld4 extends ComponentGateway {

    //-------------------- ComponentGateway ----------------------
    /**
     * Handle the default HttpRequest. 
     */
    public Document handleDefault (BComponent root, ViewContext vc, HttpServletRequest req, HttpServletResponse resp) throws IOException {

        //find our target locale
        Locale locale = vc.getViewCapabilities().getClientLocale();
                
        //load the localized DOM template
        Document page = DefaultDOMLoader.getGlobalInstance().getDOM(HelloWorld4HTML.class, locale);

        //create the component and bind it to the views
        BTemplate templateComp = new BTemplate();
        templateComp.addView(new DefaultTemplateView(page.getElementById("HelloWorldHdr")));
        templateComp.addView(new DefaultTemplateView(page.getElementById("HelloWorldList")));

        //now specify the model
        templateComp.addModel(new HelloWorldModel());
        ResourceBundle rb = ResourceBundle.getBundle("org.barracudamvc.tutorials.xmlc.HelloWorld4", locale); 
        String[] items = new String[] {
            Localize.getString(rb, "Groceries.Cabbage"), 
            Localize.getString(rb, "Groceries.Carrots"), 
            Localize.getString(rb, "Groceries.Mustard"), 
            Localize.getString(rb, "Groceries.Sugar"), 
            Localize.getString(rb, "Groceries.Cereal"), 
            Localize.getString(rb, "Groceries.Flour"), 
            Localize.getString(rb, "Groceries.Potatoes")
        };
        templateComp.addModel(new GroceriesModel(items));
        
        //add the component to the root
        root.addChild(templateComp);

        //return the page
        return page;
    }

    //--------------- GroceriesModel -------------------------
    /**
     * Groceries Model
     */
    class GroceriesModel extends AbstractTemplateModel implements IterativeModel {

        String[] items = null;
        int cntr = -1;

        //constructor
        public GroceriesModel(String[] iitems) {
            items = iitems;
        }

        //register the model by name
        public String getName() {return "Groceries";}

        //provide items by key
        public Object getItem(String key) {
            if (key.equals("Item")) return items[cntr];
            else return super.getItem(key);
        }

        //prepare for iteration
        public void preIterate() {
            cntr = -1;
        }
        
        //return true if there are more rows in the data model
        public boolean hasNext() {
            return (cntr<(items.length-1));
        }
        
        //load the next row in the model
        public void loadNext() {
            cntr++;
        }

        //cleanup after iteration
        public void postIterate() {}
    }

    //--------------- HelloWorldModel ------------------------
    /**
     * HelloWorldModel
     */
    class HelloWorldModel extends AbstractTemplateModel {
    
        //register the model by name
        public String getName() {return "HelloWorld";}
        
        //provide items by key
        public Object getItem(String key) {
            ViewContext vc = getViewContext();
            if (key.equals("Hdr")) {
//csc_072604_2                Document masterDoc = vc.getElementFactory().getDocument();
                Document masterDoc = vc.getDocument();  //csc_072604_2
                try {
                    Node headerNode = DefaultDOMLoader.getGlobalInstance().getDOM(HelloWorld4_headerHTML.class).getElementById("Header");
                    return masterDoc.importNode(headerNode, true);            
                } catch (IOException e) {
                    return null;
                }
            } else return super.getItem(key);
        }
    }
}
