/*
 * Copyright (C) 2003  Christian Cryder [christianc@granitepeaks.com]
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * $Id: TestDateValidator.java 114 2005-12-09 15:51:51Z christianc $
 */
package org.barracudamvc.core.forms.validators;

import java.util.*;
import junit.framework.*;

import org.barracudamvc.core.forms.*;
import org.apache.log4j.*;
import org.barracudamvc.plankton.data.*;
import org.barracudamvc.testbed.*;

/**
 * This test verifies that DateValidator works correctly.
 */
public class TestDateValidator extends ValidatorTestCase {

	//common vars (customize for every test class)
	private static String testClass = TestDateValidator.class.getName();
	private static Logger logger = Logger.getLogger("test."+testClass);

	//variables
	
	//-------------------- Basics --------------------------------

	/**
	 * Public Constructor
	 */
	public TestDateValidator(String name) {
		super(name);
	}
	
	/**
	 * Every test class should have a main method so it can be run
	 * directly (when debugging tests you often will not want to run
	 * the whole suite)
	 *
	 * @param args defined in test.util.TestUtil
	 */
	public static void main(String args[]) {
		//check for standard runtime parameters
		TestUtil.parseParams(args);

		//launch the test
		if (TestUtil.BATCH_MODE) junit.textui.TestRunner.main(new String[] {testClass});
		else junit.swingui.TestRunner.main(new String[] {testClass});
	}

	public static Test suite() {

		TestSuite allLocalesSuite = new TestSuite();

		Locale[] availableLocales = Locale.getAvailableLocales();
		for (int i = 0; i < availableLocales.length; i++) {
            //csc_082603_2
            //ok, skip the thai locale until we have someone who knows enough about it to be able
            //to say what are valid dates and what aren't. Thai uses a solar calendar, which means
            //what we consider to be leap years aren't. This was causing test cases to fail, and since 
            //I don't know enough about thai to know what's actually correct, for now I am just removing
            //this from the test case.
            if (availableLocales[i].getLanguage().equals("th") && availableLocales[i].getCountry().equals("TH")) continue;
			
            //build the test suite 
            TestSuite suite = new TestSuite();
			suite.addTestSuite( TestDateValidator.class );
			allLocalesSuite.addTest( new LocaleTestSuiteSetup( suite, availableLocales[i]) );
			logger.info("Adding:" + availableLocales[i].getCountry() );
		}

		return allLocalesSuite;
	}
	
	//-------------------- Actual Tests --------------------------
	//Note: all the methods herein should follow the testXXXX naming convention
	//Also keep in mind that local vars set in one test method are NOT retained
	//when the next method is invoked because JUnit makes a separate instance of
	//the test class for each testXXXX method!!!
	
	/**
	 * Test String types
	 */
	public void testString() {
        logger.info("Locale:"+Locale.getDefault());

		DateValidator v = new DateValidator();

		// ilc_022502.1_start
        // added going through the mapping process
        DefaultStateMap sm = new DefaultStateMap();
        sm.putState("InvalidString1", "foo");
        sm.putState("InvalidString2", TestUtil.dateStringInDefaultLocaleShortForm("2000", "1", "32"));
        sm.putState("InvalidString3", TestUtil.dateStringInDefaultLocaleShortForm("1999", "13", "1"));
        sm.putState("InvalidString4", TestUtil.dateStringInDefaultLocaleShortForm("2001", "2", "29"));
        sm.putState("InvalidString5", TestUtil.dateStringInDefaultLocaleShortForm("2000", "01", "32"));
        sm.putState("InvalidString6", TestUtil.dateStringInDefaultLocaleShortForm("1999", "13", "01"));
        sm.putState("InvalidString7", TestUtil.dateStringInDefaultLocaleShortForm("2001", "02", "29"));
        sm.putState("InvalidString8", TestUtil.dateStringInDefaultLocaleShortForm("2002", "01", "32"));
        sm.putState("InvalidString9", TestUtil.dateStringInDefaultLocaleShortForm("2010", "13", "01"));
        sm.putState("InvalidString10", TestUtil.dateStringInDefaultLocaleShortForm("2013", "02", "29"));


        this.assertAllInvalid(v, sm, FormType.STRING);

        sm = null;
        sm = new DefaultStateMap();
        sm.putState("ValidString1", "");
        sm.putState("ValidString2", null);
        sm.putState("ValidString3", TestUtil.dateStringInDefaultLocaleShortForm("2001", "1", "1"));
        sm.putState("ValidString4", TestUtil.dateStringInDefaultLocaleShortForm("2005", "1", "1"));
        sm.putState("ValidString5", TestUtil.dateStringInDefaultLocaleShortForm("2001", "12", "1"));
        sm.putState("ValidString6", TestUtil.dateStringInDefaultLocaleShortForm("2000", "2", "29"));
        sm.putState("ValidString7", TestUtil.dateStringInDefaultLocaleShortForm("2004", "2", "29"));
        sm.putState("ValidString8", TestUtil.dateStringInDefaultLocaleShortForm("1999", "12", "31"));
        sm.putState("ValidString9", TestUtil.dateStringInDefaultLocaleShortForm("2010", "12", "31"));
        sm.putState("ValidString10", TestUtil.dateStringInDefaultLocaleShortForm("2001", "01", "01"));
        sm.putState("ValidString11", TestUtil.dateStringInDefaultLocaleShortForm("2005", "01", "01"));
        sm.putState("ValidString12", TestUtil.dateStringInDefaultLocaleShortForm("2001", "12", "01"));
        sm.putState("ValidString13", TestUtil.dateStringInDefaultLocaleShortForm("2000", "02", "29"));
        sm.putState("ValidString14", TestUtil.dateStringInDefaultLocaleShortForm("2004", "02", "29"));

        this.assertAllValid(v, sm, FormType.STRING);
	}

	public void testLong() {
/*
		DateValidator v = new DateValidator();
		DefaultFormElement el = new DefaultFormElement("key", FormType.LONG);

        // ilc_022502.3_start
        // do testing by going through the mapping process
        DefaultStateMap sm = new DefaultStateMap();

        sm.putState("InvalidLong1", new Long(0));
        sm.putState("InvalidLong1", new Long(1));
        sm.putState("InvalidLong1", new Long(-1));
        sm.putState("InvalidLong1", new Long(Long.MIN_VALUE));
        sm.putState("InvalidLong1", new Long(Long.MAX_VALUE));

        this.assertAllInvalid(v, sm, FormType.LONG);
*/        
	}
	
	public void testBoolean() {
/*    
		DateValidator v = new DateValidator();
		DefaultFormElement el = new DefaultFormElement("key", FormType.BOOLEAN);

        // ilc_022502.5_start
        // use a StateMap for testing to make sure elements go through mapping
        DefaultStateMap sm = new DefaultStateMap();

        sm.putState("BooleanInvalid1", Boolean.FALSE);
        sm.putState("BooleanInvalid2", Boolean.TRUE);

        this.assertAllInvalid(v, sm, FormType.BOOLEAN);

        sm = null;
        sm = new DefaultStateMap();
        sm.putState("BooleanValid1", null);
        this.assertAllValid(v, sm, FormType.BOOLEAN);

        // ilc_022502.5_end
*/        
	}
	
	public void testShort() {
/*
		DateValidator v = new DateValidator();
		DefaultFormElement el = new DefaultFormElement("key", FormType.SHORT);
        // ilc_022502.7_start
        // use a StateMap for testing to make sure elements go through mapping
        DefaultStateMap sm = new DefaultStateMap();

        sm.putState("ShortInvalid1", new Short((short)0));
        sm.putState("ShortInvalid2", new Short((short)1));
        sm.putState("ShortInvalid3", new Short((short)-1));
        sm.putState("ShortInvalid4", new Short(Short.MIN_VALUE));
        sm.putState("ShortInvalid5", new Short(Short.MAX_VALUE));


        this.assertAllInvalid(v, sm, FormType.SHORT);

        sm = null;
        sm = new DefaultStateMap();
        sm.putState("ShortValid1", null);
        this.assertAllValid(v, sm, FormType.SHORT);

        // ilc_022502.7_end
*/        
	}
	
	public void testInteger() {
/*
		DateValidator v = new DateValidator();
		DefaultFormElement el = new DefaultFormElement("key", FormType.INTEGER);
        // ilc_022502.9_start
        // use a StateMap for testing to make sure elements go through mapping
        DefaultStateMap sm = new DefaultStateMap();

        sm.putState("IntegerInvalid1", new Integer(0));
        sm.putState("IntegerInvalid2", new Integer(1));
        sm.putState("IntegerInvalid3", new Integer(-1));
        sm.putState("IntegerInvalid4", new Integer(Integer.MIN_VALUE));
        sm.putState("IntegerInvalid5", new Integer(Integer.MAX_VALUE));

        this.assertAllInvalid(v, sm, FormType.INTEGER);

        sm = null;
        sm = new DefaultStateMap();
        sm.putState("IntegerValid1", null);
        this.assertAllValid(v, sm, FormType.INTEGER);

        // ilc_022502.9_end
*/        
	}
	
	public void testDate()  {
/*    
		DateValidator v = new DateValidator();
		DefaultFormElement el = new DefaultFormElement("key", FormType.DATE);

		DateFormat aDateFormat = DateFormat.getDateInstance(DateFormat.SHORT);
		aDateFormat.setLenient(false);


        // ilc_022202.11_start
        // use a StateMap for testing to make sure elements go through mapping
        DefaultStateMap sm = new DefaultStateMap();

        try {
          sm.putState("DateValid1", null);
          sm.putState("DateValid1", new Date());
          sm.putState("DateValid1", aDateFormat.parse(TestUtil.dateStringInDefaultLocaleShortForm("2001", "1", "1")));
          sm.putState("DateValid1", aDateFormat.parse(TestUtil.dateStringInDefaultLocaleShortForm("2005", "1", "1")));
          sm.putState("DateValid1", aDateFormat.parse(TestUtil.dateStringInDefaultLocaleShortForm("2000", "2", "29")));
          sm.putState("DateValid1", aDateFormat.parse(TestUtil.dateStringInDefaultLocaleShortForm("2004", "2", "29")));
          sm.putState("DateValid1", aDateFormat.parse(TestUtil.dateStringInDefaultLocaleShortForm("1999", "12", "31")));
          sm.putState("DateValid1", aDateFormat.parse(TestUtil.dateStringInDefaultLocaleShortForm("2001", "01", "01")));
          sm.putState("DateValid1", aDateFormat.parse(TestUtil.dateStringInDefaultLocaleShortForm("2005", "01", "1")));

        } catch(java.text.ParseException ex) {
          fail( "testDate failed because " + ex.getMessage() );
        }
        // ilc_022502.11_end
*/        
	}
	
	public void testDouble() {
/*
		DateValidator v = new DateValidator();
		DefaultFormElement el = new DefaultFormElement("key", FormType.DOUBLE);
        // ilc_022502.13_start
        // use a StateMap for testing to make sure elements go through mapping
        DefaultStateMap sm = new DefaultStateMap();

        sm.putState("DoubleInvalid1", new Double(0));
        sm.putState("DoubleInvalid2", new Double(1));
        sm.putState("DoubleInvalid3", new Double(-1));
        sm.putState("DoubleInvalid4", new Double(Double.MIN_VALUE));
        sm.putState("DoubleInvalid5", new Double(Double.MAX_VALUE));

        this.assertAllInvalid(v, sm, FormType.DOUBLE);

        sm = null;
        sm = new DefaultStateMap();
        sm.putState("DoubleValid1", null);
        this.assertAllValid(v, sm, FormType.DOUBLE);

        // ilc_022502.13_end
*/        
	}
	
	public void testFloat() {
/*    
		DateValidator v = new DateValidator();
		DefaultFormElement el = new DefaultFormElement("key", FormType.FLOAT);
        // ilc_022502.15_start
        // use a StateMap for testing to make sure elements go through mapping
        DefaultStateMap sm = new DefaultStateMap();

        sm.putState("FloatInvalid1", new Float(0));
        sm.putState("FloatInvalid2", new Float(1));
        sm.putState("FloatInvalid3", new Float(-1));
        sm.putState("FloatInvalid4", new Float(Float.MIN_VALUE));
        sm.putState("FloatInvalid5", new Float(Float.MAX_VALUE));

        this.assertAllInvalid(v, sm, FormType.FLOAT);

        sm = null;
        sm = new DefaultStateMap();
        sm.putState("FloatValid1", null);
        this.assertAllValid(v, sm, FormType.FLOAT);

        // ilc_022502.15_end
*/
	}
}
