/*
 * Copyright (C) 2003  Christian Cryder [christianc@granitepeaks.com]
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * $Id: TestHttpConverter.java 114 2005-12-09 15:51:51Z christianc $
 */
package org.barracudamvc.plankton.http;

import java.util.*;

import org.apache.log4j.*;
import org.barracudamvc.testbed.*;


/**
 * This test verifies the Param object
 */
public class TestHttpConverter extends DefaultTestCase {
    //common vars (customize for every test class)
    private static String testClass = TestHttpConverter.class.getName();
    private static Logger logger = Logger.getLogger("test."+testClass);

    //variables

    //-------------------- Basics --------------------------------
    /**
     * Public Constructor
     */
    public TestHttpConverter(String name) {
        super(name);
    }

    /**
     * Every test class should have a main method so it can be run
     * directly (when debugging tests you often will not want to run
     * the whole suite)
     *
     * @param args defined in test.util.TestUtil
     */
    public static void main(String args[]) {
        //check for standard runtime parameters
        TestUtil.parseParams(args);

        //launch the test
        if (TestUtil.BATCH_MODE) junit.textui.TestRunner.main(new String[] {testClass});
        else junit.swingui.TestRunner.main(new String[] {testClass});
    }


    //-------------------- Actual Tests --------------------------
    //Note: all the methods herein should follow the testXXXX naming convention
    //Also keep in mind that local vars set in one test method are NOT retained
    //when the next method is invoked because JUnit makes a separate instance of
    //the test class for each testXXXX method!!!

    /**
     * Simple test to make sure the Param object works
     */
    public void testHttpConverter() {
        if (logger.isInfoEnabled()) logger.info("testing http conversion");

        //make sure the basic encoding works
        String ourl = "hello 100% - Ma & Pa";
        String eurl = HttpConverter.encode(ourl);
        String durl = HttpConverter.decode(eurl);
//System.out.println("basic encode/decode \n   orig:"+ourl+" \nencoded:"+eurl+" \ndecoded:"+durl);        
        assertTrue("Basic encode/decode failed - orig:"+ourl+" encoded:"+eurl+" decoded:"+durl, ourl.equals(durl));

        //now make sure we can go from a map to a string and back to a map correctly
        Map m1 = new HashMap();
        m1.put("Key1&75", "hello 100% - Ma & Pa");
        m1.put("Key2&75", "hello 100% - Ma & Pa");
        m1.put("Key3&75", "hello 100% - Ma & Pa");
        String url = HttpConverter.cvtMapToURLString(m1);
//System.out.println("url:"+url);        
        Map m2 = HttpConverter.cvtURLStringToMap(url);
//CollectionsUtil.printStackTrace(m2);
        assertTrue("Map to url to map encode/decode failed", m1.equals(m2));        
    }
}
