/*
 * Copyright (C) 2003  Christian Cryder [christianc@granitepeaks.com]
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * $Id: TestBetterPipedReader.java 114 2005-12-09 15:51:51Z christianc $
 */
package org.barracudamvc.plankton.io;

import java.io.*;
import java.util.*;
import junit.framework.*;

import org.apache.log4j.*;
import org.barracudamvc.testbed.*;


/**
 * This test verifies the BetterPipedReader object
 */
public class TestBetterPipedReader extends DefaultTestCase {
    //common vars (customize for every test class)
    private static String testClass = TestBetterPipedReader.class.getName();
    private static Logger logger = Logger.getLogger("test."+testClass);

    //variables
    String srcstr = null;
    
    //-------------------- Basics --------------------------------
    /**
     * Public Constructor
     */
    public TestBetterPipedReader(String name) {
        super(name);
    }
    public TestBetterPipedReader(String name, String isrcstr) {
        super(name);
        srcstr = isrcstr;
    }

    /**
     * Every test class should have a main method so it can be run
     * directly (when debugging tests you often will not want to run
     * the whole suite)
     *
     * @param args defined in test.util.TestUtil
     */
    public static void main(String args[]) {
        //check for standard runtime parameters
        TestUtil.parseParams(args);

        //launch the test
        if (TestUtil.BATCH_MODE) junit.textui.TestRunner.main(new String[] {testClass});
        else junit.swingui.TestRunner.main(new String[] {testClass});
    }

    /**
     * Return a suite of tests...
     */
    public static Test suite() {
        //create the test suite
        TestSuite suite = new TestSuite();

        for (int i=1; i<3000; i++) {
            //add the tests
            byte[] bytes = new byte[i];
            new Random().nextBytes(bytes);
            suite.addTest(new TestBetterPipedReader("testReader", new String(bytes)));
        }

        //finally return the suite
        return suite;
    }

    //-------------------- Actual Tests --------------------------
    //Note: all the methods herein should follow the testXXXX naming convention
    //Also keep in mind that local vars set in one test method are NOT retained
    //when the next method is invoked because JUnit makes a separate instance of
    //the test class for each testXXXX method!!!

    /**
     * Simple test to make sure the Param object works
     */
    public void testReader() throws IOException {
        if (logger.isInfoEnabled()) logger.info("testing reader");

        //create the reader/writer
        BetterPipedWriter pw = new BetterPipedWriter();
        BetterPipedReader pr = new BetterPipedReader();
        pr.connect(pw);

        //write the string (this should cause the writer to expand as needed, since we haven't started reading yet)
        pw.write(srcstr);
        pw.close();    
        
        //read the string
        StringBuffer sb2 = new StringBuffer(srcstr.length());
        int len = 1024;
        char[] data = new char[len];
        while (true) {
            int cnt = pr.read(data, 0, len);
            if (cnt==-1) break;
            sb2.append(data, 0, cnt);
        }
        String s2 = sb2.toString();
        
        //check for equality
        assertEquals("["+srcstr.length()+"] s1!=s2", srcstr, s2);
        
        pr.close();
    }
}
