/*
 * Copyright (C) 2003  Christian Cryder [christianc@granitepeaks.com]
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * $Id: TestFileNames.java 114 2005-12-09 15:51:51Z christianc $
 */
package org.barracudamvc.taskdefs;

import java.io.IOException;

import org.enhydra.xml.xmlc.taskdef.*;

import org.barracudamvc.testbed.*;

/**
 * Unit tests for buildFullBaseFileName() and buildClassName() methods
 * of DefaultXmlcUtilsImpl
 */
public class TestFileNames extends DefaultTestCase {

    //===========================================================================
    // CONSTRUCTORS
    //===========================================================================

    /**
     * Default constructor
     *
     * @param theName   The name of the test
     */
    public TestFileNames( String theName) {
        super( theName );
    }

    /**
     * Sets up the fixture, for example, open a network connection.
     * This method is called before a test is executed.
     */
    protected void setUp() throws Exception {
        super.setUp();
    }

    /**
     * Tears down the fixture, for example, close a network connection.
     * This method is called after a test is executed.
     */
    protected void tearDown() throws Exception {
        super.tearDown();
    }

    //===========================================================================
    // TEST METHODS
    //===========================================================================
    public void testBasicBuildFullBaseFileName() throws IOException {
        XmlcUtils xmlcUtils = XmlcUtils.create();

        String baseFilename = "base";
        String newBaseFileName = xmlcUtils.buildFullBaseFileName( null, null, baseFilename );
        assertEquals("Name should be unchanged", baseFilename, newBaseFileName );

        baseFilename = "base.html";
        String expectedBaseFileName = "base";
        newBaseFileName = xmlcUtils.buildFullBaseFileName( null, null, baseFilename );
        assertEquals("Type should be stripped off", expectedBaseFileName, newBaseFileName );
    }

    public void testPackageNameBuildFullBaseFileName() throws IOException {
        XmlcUtils xmlcUtils = XmlcUtils.create();

        String baseFilename = "base";

        String packageName = "a";
        String expectedBaseFileName = "a/" + baseFilename;
        String newBaseFileName = xmlcUtils.buildFullBaseFileName( packageName, null, baseFilename );
        assertEquals("Name 0 should be as expected",
                     expectedBaseFileName,
                     newBaseFileName );

        packageName = "";
        expectedBaseFileName = baseFilename;
        newBaseFileName = xmlcUtils.buildFullBaseFileName( packageName, null, baseFilename );
        assertEquals("Name should be unchanged",
                     expectedBaseFileName,
                     newBaseFileName );

        packageName = "a.b.c.d";
        expectedBaseFileName = "a/b/c/d/" + baseFilename;
        newBaseFileName = xmlcUtils.buildFullBaseFileName( packageName, null, baseFilename );
        assertEquals("Name 1 should be as expected",
                     expectedBaseFileName,
                     newBaseFileName );

        packageName = "p1.p2.p3.p4.p5.";
        expectedBaseFileName = "p1/p2/p3/p4/p5/" + baseFilename;
        newBaseFileName = xmlcUtils.buildFullBaseFileName( packageName, null, baseFilename );
        assertEquals("Name 2 should be as expected",
                     expectedBaseFileName,
                     newBaseFileName );

        baseFilename = "/test1/test2/test3/base";
        packageName = "";
        expectedBaseFileName = baseFilename;
        newBaseFileName = xmlcUtils.buildFullBaseFileName( packageName, null, baseFilename );
        assertEquals("Name should be unchanged again",
                     expectedBaseFileName,
                     newBaseFileName );

        packageName = "a.b.c.d.";
        expectedBaseFileName = "a/b/c/d" + baseFilename;
        newBaseFileName = xmlcUtils.buildFullBaseFileName( packageName, null, baseFilename );
        assertEquals("Name 3 should be as expected",
                     expectedBaseFileName,
                     newBaseFileName );
    }

    public void testPackageDirBuildFullBaseFileName() throws IOException {
        XmlcUtils xmlcUtils = XmlcUtils.create();

        String baseFilename = "base";
        String packageDir = "a";
        String expectedBaseFileName = "a/" + baseFilename;
        String newBaseFileName = xmlcUtils.buildFullBaseFileName( null, packageDir, baseFilename );
        assertEquals("Name 0 should be as expected",
                     expectedBaseFileName,
                     newBaseFileName );

        baseFilename = "test.base";
        packageDir = "";
        expectedBaseFileName = "test";
        newBaseFileName = xmlcUtils.buildFullBaseFileName( null, packageDir, baseFilename );
        assertEquals("Name 1 should be as expected",
                     expectedBaseFileName,
                     newBaseFileName );

        baseFilename = "\\base";
        packageDir = "a/";
        expectedBaseFileName = "a/" + "base";
        newBaseFileName = xmlcUtils.buildFullBaseFileName( null, packageDir, baseFilename );
        assertEquals("Name 2 should be as expected",
                     expectedBaseFileName,
                     newBaseFileName );

        baseFilename = "/test1/test2/test3/base";
        packageDir = "a/b/c/d";
        expectedBaseFileName = "a/b/c/d/" + "base";
        newBaseFileName = xmlcUtils.buildFullBaseFileName( null, packageDir, baseFilename );
        assertEquals("Name 3 should be as expected",
                     expectedBaseFileName,
                     newBaseFileName );

        baseFilename = "test1\\test2/test3\\base/";
        packageDir = "\\a/b\\c/d\\";
        expectedBaseFileName = "/a/b/c/d/" + "base";
        newBaseFileName = xmlcUtils.buildFullBaseFileName( null, packageDir, baseFilename );
        assertEquals("Name 4 should be as expected",
                     expectedBaseFileName,
                     newBaseFileName );
    }

    public void testBuildFullBaseFileName() throws IOException {
        XmlcUtils xmlcUtils = XmlcUtils.create();

        String baseFilename = "base";
        String packageName = "packageName";
        String packageDir = "packageDir";
        String expectedBaseFileName = packageName + "/" + packageDir + "/" + baseFilename;
        String newBaseFileName = xmlcUtils.buildFullBaseFileName( packageName, packageDir, baseFilename );
        assertEquals("Name 0 should be as expected",
                     expectedBaseFileName,
                     newBaseFileName );

        baseFilename = "/dir1/dir2/dir3/base.test.test";
        packageName = "name1.name2.name3....";
        packageDir = "/dirA/dirB/dirc/";
        expectedBaseFileName = "name1/name2/name3" + packageDir + "base";
        newBaseFileName = xmlcUtils.buildFullBaseFileName( packageName, packageDir, baseFilename );
        assertEquals("Name 1 should be as expected",
                     expectedBaseFileName,
                     newBaseFileName );

        baseFilename = "/dir1/dir2/dir3/base.test.test";
        packageName = "name1.name2.name3....";
        packageDir = "";
        expectedBaseFileName = "name1/name2/name3/" + "dir1/dir2/dir3/base";
        newBaseFileName = xmlcUtils.buildFullBaseFileName( packageName, packageDir, baseFilename );
        assertEquals("Name 2 should be as expected",
                     expectedBaseFileName,
                     newBaseFileName );
    }

    public void testBuildClassName() throws IOException {
        XmlcUtils xmlcUtils = XmlcUtils.create();

        String filename = "p1/p2/p3/base";
        String typeModifier = "HTML";
        String expectedClassName = "p1.p2.p3.baseHTML";
        String newClassName = xmlcUtils.buildClassName( filename, typeModifier );
        assertEquals("Class 0 should be as expected",
                     expectedClassName,
                     newClassName );
    }

}
